# instructions for Claude

## Code style

- Python is used for the backend (in the root directory of the project)

## Python

- this codebase uses `uv` as the package manager
- after modifying any python code, format it with `black`

## Workflow

- Prefer running single tests, and not the whole test suite, for performance
